Package 'rk.names.labels'
| Title: |
A plugin package to clean and create names and labels of
variables of a data.frame or manipulate names in a list in the
Rkward GUI. |
| Description: |
A plugin package to clean and create names and labels of
variables of a data.frame or manipulate names in a list in the
Rkward GUI. |
| Authors: |
Alfonso Cano |
| Maintainer: |
Alfonso Cano <[email protected]> |
| License: |
GPL (>= 3) |
| Version: |
0.0.5 |
| Built: |
2026-06-05 07:05:42 UTC |
| Source: |
https://github.com/AlfCano/rk.names.labels |
Help Index